#[non_exhaustive]pub enum TrustError {
UnknownIdentity {
did: String,
policy: String,
},
KeyResolutionFailed {
did: String,
},
InvalidTrustStore(String),
TofuRequiresInteraction,
}Expand description
Errors from trust policy resolution during verification.
Usage:
ⓘ
match resolve_issuer_key(did, policy) {
Err(TrustError::UnknownIdentity { did, policy }) => {
eprintln!("Unknown identity under {} policy; run `auths trust pin --did {}`", policy, did)
}
Err(e) => return Err(e.into()),
Ok(key) => { /* use key for verification */ }
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownIdentity
Identity is unknown and trust policy does not permit TOFU/resolution.
Fields
KeyResolutionFailed
Identity exists but no public key could be resolved.
InvalidTrustStore(String)
The provided roots.json or trust store is invalid.
TofuRequiresInteraction
TOFU prompt was required but execution is non-interactive.