#[non_exhaustive]pub enum DeviceError {
IdentityNotFound {
did: String,
},
DeviceNotFound {
did: String,
},
AttestationError(AttestationError),
DeviceDidMismatch {
expected: String,
actual: String,
},
CryptoError(AgentError),
StorageError(SdkStorageError),
AnchorError(AnchorError),
DelegationError(InitError),
}Expand description
Errors from device linking and revocation operations.
Usage:
ⓘ
match link_result {
Err(DeviceError::IdentityNotFound { did }) => { /* identity missing */ }
Err(e) => return Err(e.into()),
Ok(result) => { /* success */ }
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IdentityNotFound
The identity could not be found in storage.
DeviceNotFound
The device could not be found in attestation records.
AttestationError(AttestationError)
Attestation creation or validation failed.
DeviceDidMismatch
The device DID derived from the key does not match the expected DID.
Fields
CryptoError(AgentError)
A cryptographic operation failed.
StorageError(SdkStorageError)
A storage operation failed.
AnchorError(AnchorError)
Anchoring the attestation in the KEL failed.
DelegationError(InitError)
Authoring or anchoring a delegated device identifier failed.