#[non_exhaustive]pub enum OrgError {
AdminNotFound {
org: String,
},
MemberNotFound {
org: String,
did: String,
},
AlreadyRevoked {
did: String,
},
InvalidCapability {
cap: String,
reason: String,
},
InvalidDid(String),
InvalidPublicKey(String),
Storage(String),
}Expand description
Errors from organization member management workflows.
Usage:
ⓘ
match result {
Err(OrgError::AdminNotFound { .. }) => { /* 403 Forbidden */ }
Err(OrgError::MemberNotFound { .. }) => { /* 404 Not Found */ }
Err(e) => return Err(e.into()),
Ok(att) => { /* proceed */ }
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AdminNotFound
No admin matching the given public key was found in the organization.
MemberNotFound
The specified member was not found in the organization.
Fields
AlreadyRevoked
The member has already been revoked.
InvalidCapability
The capability string could not be parsed.
InvalidDid(String)
The organization DID is malformed.
InvalidPublicKey(String)
The hex-encoded public key is invalid.
Storage(String)
A storage operation failed.