RotationError

Enum RotationError 

#[non_exhaustive]
pub enum RotationError { IdentityNotFound { path: PathBuf, }, KeyNotFound(String), KeyDecryptionFailed(String), KelHistoryFailed(String), RotationFailed(String), PartialRotation(String), }
Errors from identity rotation operations.

Usage:

match rotate_result {
    Err(RotationError::KelHistoryFailed(msg)) => { /* no prior events */ }
    Err(e) => return Err(e.into()),
    Ok(result) => { /* success */ }
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


IdentityNotFound

The identity was not found at the expected path.

Fields

path: PathBuf

The filesystem path where the identity was expected.



KeyNotFound(String)

The requested key alias was not found in the keychain.



KeyDecryptionFailed(String)

Decrypting the key material failed (e.g. wrong passphrase).



KelHistoryFailed(String)

Reading or validating the KEL history failed.



RotationFailed(String)

The rotation operation failed.



PartialRotation(String)

KEL event was written but the new key could not be persisted to the keychain. Recovery: re-run rotation with the same new key to replay the keychain write.