pub struct PackageName(/* private fields */);Expand description
Validated package name within an ecosystem.
Rejects empty strings, control characters, and path traversal patterns.
Usage:
ⓘ
let name = PackageName::parse("my-package")?;
assert_eq!(name.as_str(), "my-package");Implementations
Sourceimpl PackageName
impl PackageName
Sourcepub fn parse(s: &str) -> Result<PackageName, NamespaceVerifyError>
pub fn parse(s: &str) -> Result<PackageName, NamespaceVerifyError>
Parse and validate a package name string.
Args:
s: The package name to validate.
Usage:
ⓘ
let name = PackageName::parse("left-pad")?;Trait Implementations
Sourceimpl Clone for PackageName
impl Clone for PackageName
Sourcefn clone(&self) -> PackageName
fn clone(&self) -> PackageName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PackageName
impl Debug for PackageName
Sourceimpl<'de> Deserialize<'de> for PackageName
impl<'de> Deserialize<'de> for PackageName
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PackageName, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PackageName, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for PackageName
impl Display for PackageName
impl Eq for PackageName
Sourceimpl Hash for PackageName
impl Hash for PackageName
Sourceimpl PartialEq for PackageName
impl PartialEq for PackageName
Sourcefn eq(&self, other: &PackageName) -> bool
fn eq(&self, other: &PackageName) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PackageName
impl Serialize for PackageName
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for PackageName