#[non_exhaustive]pub enum SigningError {
IdentityFrozen(String),
KeyResolution(String),
SigningFailed(String),
InvalidPassphrase,
PemEncoding(String),
AgentUnavailable(String),
AgentSigningFailed(AgentSigningError),
PassphraseExhausted {
attempts: usize,
},
KeychainUnavailable(String),
KeyDecryptionFailed(String),
}Expand description
Errors from the signing pipeline.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IdentityFrozen(String)
The identity is in a freeze state and signing is not permitted.
KeyResolution(String)
The requested key alias could not be resolved from the keychain.
SigningFailed(String)
The cryptographic signing operation failed.
InvalidPassphrase
The supplied passphrase was incorrect.
PemEncoding(String)
SSHSIG PEM encoding failed after signing.
The agent is not available (platform unsupported, not installed, or not reachable).
AgentSigningFailed(AgentSigningError)
The agent accepted the signing request but it failed.
PassphraseExhausted
All passphrase attempts were exhausted without a successful decryption.
The platform keychain could not be accessed.
KeyDecryptionFailed(String)
The encrypted key material could not be decrypted.