pub struct DeviceExtensionConfig {
pub repo_path: PathBuf,
pub device_did: String,
pub days: u32,
pub identity_key_alias: KeyAlias,
pub device_key_alias: KeyAlias,
}Expand description
Configuration for extending a device authorization’s expiration.
Args:
repo_path: Path to the auths registry.device_did: The DID of the device whose authorization to extend.days: Number of days from now for the new expiration.identity_key_alias: Keychain alias for the identity key (for re-signing).device_key_alias: Keychain alias for the device key (for re-signing).
Usage:
ⓘ
let config = DeviceExtensionConfig {
repo_path: PathBuf::from("/home/user/.auths"),
device_did: "did:key:z6Mk...".into(),
days: 365,
identity_key_alias: "my-identity".into(),
device_key_alias: "my-device".into(),
};Fields
repo_path: PathBufPath to the auths registry.
device_did: StringDID of the device whose authorization to extend.
days: u32Number of days from now for the new expiration.
identity_key_alias: KeyAliasKeychain alias for the identity signing key.
device_key_alias: KeyAliasKeychain alias for the device signing key.