pub enum CommitHookError {
Write {
path: PathBuf,
source: Error,
},
GitConfig(GitConfigError),
NonUtf8Path(PathBuf),
Signer(String),
}Expand description
Failure installing the commit hook or writing its data files.
Variants
Write
A hook or data file could not be written.
GitConfig(GitConfigError)
Setting core.hooksPath failed.
NonUtf8Path(PathBuf)
The hooks directory path is not representable as UTF-8 for git config.
Signer(String)
The local signing identity could not be resolved for a trailer refresh.