DiagnosticsWorkflow

Struct DiagnosticsWorkflow 

pub struct DiagnosticsWorkflow<G: GitDiagnosticProvider, C: CryptoDiagnosticProvider> { /* private fields */ }
Orchestrates diagnostic checks without subprocess calls.

Args:

Usage:

let workflow = DiagnosticsWorkflow::new(posix_adapter.clone(), posix_adapter);
let report = workflow.run()?;

Implementations

Source

impl<G: GitDiagnosticProvider, C: CryptoDiagnosticProvider> DiagnosticsWorkflow<G, C>

pub fn new(git: G, crypto: C) -> Self

Create a new diagnostics workflow with the given providers.

pub fn run(&self) -> Result<DiagnosticReport, DiagnosticError>

Run all diagnostic checks and return the aggregated report.

Usage:

let report = workflow.run()?;
assert!(report.checks.iter().all(|c| c.passed));