pub enum PinRootError {
Store(ConfigStoreError),
Index(IndexError),
}Expand description
Failure pinning a trusted root into a repository.
Variants
Store(ConfigStoreError)
The pin file could not be read or written.
Index(IndexError)
The pin file could not be staged into the index.