AuthsContextBuilder

Struct AuthsContextBuilder 

pub struct AuthsContextBuilder<R, K, C, IS, AS, ASrc> { /* private fields */ }
Typestate builder for AuthsContext.

Call AuthsContext::builder() to obtain an instance. The build() method is only available once all six required fields have been supplied — omitting any produces a compile-time error.

Implementations

Source

impl<K, C, IS, AS, ASrc> AuthsContextBuilder<Missing, K, C, IS, AS, ASrc>

pub fn registry( self, registry: Arc<dyn RegistryBackend + Send + Sync>, ) -> AuthsContextBuilder<Set<Arc<dyn RegistryBackend + Send + Sync>>, K, C, IS, AS, ASrc>

Set the registry storage backend.

Args:

  • registry: Pre-initialized registry backend.

Usage:

builder.registry(Arc::new(my_git_backend))
Source

impl<R, C, IS, AS, ASrc> AuthsContextBuilder<R, Missing, C, IS, AS, ASrc>

pub fn key_storage( self, key_storage: Arc<dyn KeyStorage + Send + Sync>, ) -> AuthsContextBuilder<R, Set<Arc<dyn KeyStorage + Send + Sync>>, C, IS, AS, ASrc>

Set the key storage backend.

Args:

  • key_storage: Platform keychain or in-memory test fake.

Usage:

builder.key_storage(Arc::new(my_keychain))
Source

impl<R, K, IS, AS, ASrc> AuthsContextBuilder<R, K, Missing, IS, AS, ASrc>

pub fn clock( self, clock: Arc<dyn ClockProvider + Send + Sync>, ) -> AuthsContextBuilder<R, K, Set<Arc<dyn ClockProvider + Send + Sync>>, IS, AS, ASrc>

Set the clock provider.

Args:

  • clock: Wall-clock implementation (SystemClock in production, MockClock in tests).

Usage:

builder.clock(Arc::new(SystemClock))
Source

impl<R, K, C, AS, ASrc> AuthsContextBuilder<R, K, C, Missing, AS, ASrc>

pub fn identity_storage( self, storage: Arc<dyn IdentityStorage + Send + Sync>, ) -> AuthsContextBuilder<R, K, C, Set<Arc<dyn IdentityStorage + Send + Sync>>, AS, ASrc>

Set the identity storage adapter.

Args:

  • storage: Pre-initialized identity storage implementation.

Usage:

builder.identity_storage(Arc::new(my_identity_storage))
Source

impl<R, K, C, IS, ASrc> AuthsContextBuilder<R, K, C, IS, Missing, ASrc>

pub fn attestation_sink( self, sink: Arc<dyn AttestationSink + Send + Sync>, ) -> AuthsContextBuilder<R, K, C, IS, Set<Arc<dyn AttestationSink + Send + Sync>>, ASrc>

Set the attestation sink adapter.

Args:

  • sink: Pre-initialized attestation sink implementation.

Usage:

builder.attestation_sink(Arc::new(my_attestation_store))
Source

impl<R, K, C, IS, AS> AuthsContextBuilder<R, K, C, IS, AS, Missing>

pub fn attestation_source( self, source: Arc<dyn AttestationSource + Send + Sync>, ) -> AuthsContextBuilder<R, K, C, IS, AS, Set<Arc<dyn AttestationSource + Send + Sync>>>

Set the attestation source adapter.

Args:

  • source: Pre-initialized attestation source implementation.

Usage:

builder.attestation_source(Arc::new(my_attestation_store))
Source

impl<R, K, C, IS, AS, ASrc> AuthsContextBuilder<R, K, C, IS, AS, ASrc>

pub fn event_sink(self, sink: Arc<dyn EventSink>) -> Self

Set an optional event sink.

Defaults to a no-op sink (all events discarded) when not called.

Args:

Usage:

builder.event_sink(Arc::new(my_sink))
pub fn passphrase_provider( self, provider: Arc<dyn PassphraseProvider + Send + Sync>, ) -> Self

Set the passphrase provider for key decryption during signing operations.

Defaults to a noop provider that returns an error. Set this when SDK workflow functions will perform signing with encrypted key material.

Args:

Usage:

builder.passphrase_provider(Arc::new(PrefilledPassphraseProvider::new(passphrase)))
pub fn uuid_provider( self, provider: Arc<dyn UuidProvider + Send + Sync>, ) -> Self

Set the UUID provider.

Defaults to SystemUuidProvider (random v4 UUIDs) when not called. Override with a deterministic stub in tests.

Args:

Usage:

builder.uuid_provider(Arc::new(my_uuid_stub))
pub fn agent_signing( self, provider: Arc<dyn AgentSigningPort + Send + Sync>, ) -> Self

Set the agent signing port for delegating signing to a running agent process.

Defaults to a noop provider (all operations return Unavailable) when not called. Set this on Unix platforms where the auths-agent daemon is available.

Args:

Usage:

builder.agent_signing(Arc::new(CliAgentAdapter::new(socket_path)))
pub fn witness_config(self, config: WitnessConfig) -> Self

Set witness configuration for KEL event receipting.

pub fn repo_path(self, path: PathBuf) -> Self

Set the repository path (needed for witness receipt storage).

Source

impl AuthsContextBuilder<Set<Arc<dyn RegistryBackend + Send + Sync>>, Set<Arc<dyn KeyStorage + Send + Sync>>, Set<Arc<dyn ClockProvider + Send + Sync>>, Set<Arc<dyn IdentityStorage + Send + Sync>>, Set<Arc<dyn AttestationSink + Send + Sync>>, Set<Arc<dyn AttestationSource + Send + Sync>>>

pub fn build(self) -> AuthsContext

Build the AuthsContext.

Infallible — only callable once all six required fields are set. Omitting any required field is a compile-time error.

Usage:

let ctx = AuthsContext::builder()
    .registry(Arc::new(my_registry))
    .key_storage(Arc::new(my_keychain))
    .clock(Arc::new(SystemClock))
    .identity_storage(Arc::new(my_identity_storage))
    .attestation_sink(Arc::new(my_store.clone()))
    .attestation_source(Arc::new(my_store))
    .build();