#[non_exhaustive]pub enum ArtifactSigningError {
IdentityNotFound,
KeyResolutionFailed(String),
KeyDecryptionFailed(String),
DigestFailed(String),
AttestationFailed(String),
ResignFailed(String),
}Expand description
Errors from the artifact attestation signing workflow.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IdentityNotFound
No auths identity was found in the configured identity storage.
KeyResolutionFailed(String)
The key alias could not be resolved to usable key material.
KeyDecryptionFailed(String)
The encrypted key material could not be decrypted (e.g. wrong passphrase).
DigestFailed(String)
Computing the artifact digest failed.
AttestationFailed(String)
Building or serializing the attestation failed.
ResignFailed(String)
Adding the device signature to a partially-signed attestation failed.