pub struct RotationKeyMaterial {
pub did: IdentityDID,
pub next_alias: KeyAlias,
pub new_next_alias: KeyAlias,
pub old_next_alias: KeyAlias,
pub new_current_encrypted: Vec<u8>,
pub new_next_encrypted: Vec<u8>,
}Expand description
Key material required for the keychain side of apply_rotation.
Fields
did: IdentityDIDDID of the identity being rotated.
next_alias: KeyAliasAlias to store the new current key (the former pre-committed next key).
new_next_alias: KeyAliasAlias for the future pre-committed key (committed in this rotation).
old_next_alias: KeyAliasPre-committed next key alias to delete after successful rotation.
new_current_encrypted: Vec<u8>Encrypted new current key bytes to store in the keychain.
new_next_encrypted: Vec<u8>Encrypted new next key bytes to store for future rotation.